@@ -53,6 +53,7 @@ sub set {
         if ( ref $oldValue ) {
             die "$key seems to be a hash, modification refused";
         }
+        $oldValue //= '';
         push @list, [ $key, $oldValue, $pairs{$key} ];
     }
     unless ( $self->yes ) {
@@ -101,6 +102,14 @@ sub addKey {
         elsif ( $#path == 1 ) {
             $new->{ $path[0] }->{ $path[1] }->{ $el->[1] } = $el->[2];
         }
+        elsif ( $#path == 2 ) {
+            $new->{ $path[0] }->{ $path[1] }->{ $path[2] }->{ $el->[1] } =
+              $el->[2];
+        }
+        elsif ( $#path == 3 ) {
+            $new->{ $path[0] }->{ $path[1] }->{ $path[2] }->{ $path[3] }
+              ->{ $el->[1] } = $el->[2];
+        }
         else {
             die $el->[0] . " has too many levels. Aborting";
         }
@@ -133,6 +142,13 @@ sub delKey {
         elsif ( $#path == 1 ) {
             delete $new->{ $path[0] }->{ $path[1] }->{ $el->[1] };
         }
+        elsif ( $#path == 2 ) {
+            delete $new->{ $path[0] }->{ $path[1] }->{ $path[2] }->{ $el->[1] };
+        }
+        elsif ( $#path == 3 ) {
+            delete $new->{ $path[0] }->{ $path[1] }->{ $path[2] }->{ $path[3] }
+              ->{ $el->[1] };
+        }
         else {
             die $el->[0] . " has too many levels. Aborting";
         }
@@ -197,7 +213,12 @@ sub _save {
     unless ( $parser->testNewConf() ) {
         printf STDERR "Modifications rejected: %s:\n", $parser->{message};
     }
-    my $s = $self->mgr->confAcc->saveConf( $new, { force => $self->force } );
+    my $saveParams = { force => $self->force };
+    if ( $self->force and $self->cfgNum ) {
+        $saveParams->{cfgNum}      = $self->cfgNum;
+        $saveParams->{cfgNumFixed} = 1;
+    }
+    my $s = $self->mgr->confAcc->saveConf( $new, %$saveParams );
     if ( $s > 0 ) {
         print STDERR "Saved under number $s\n";
         $parser->{status} = [ $self->mgr->applyConf($new) ];
